# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class Attachment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attached_bus_ob_id': 'str',
        'attached_bus_ob_rec_id': 'str',
        'attachment_file_id': 'str',
        'attachment_file_name': 'str',
        'attachment_file_type': 'str',
        'attachment_id': 'str',
        'attachment_type': 'str',
        'bus_ob_id': 'str',
        'bus_ob_rec_id': 'str',
        'comment': 'str',
        'created': 'datetime',
        'display_text': 'str',
        'links': 'list[Link]',
        'owner': 'str',
        'scope': 'str',
        'scope_owner': 'str',
        'type': 'str'
    }

    attribute_map = {
        'attached_bus_ob_id': 'attachedBusObId',
        'attached_bus_ob_rec_id': 'attachedBusObRecId',
        'attachment_file_id': 'attachmentFileId',
        'attachment_file_name': 'attachmentFileName',
        'attachment_file_type': 'attachmentFileType',
        'attachment_id': 'attachmentId',
        'attachment_type': 'attachmentType',
        'bus_ob_id': 'busObId',
        'bus_ob_rec_id': 'busObRecId',
        'comment': 'comment',
        'created': 'created',
        'display_text': 'displayText',
        'links': 'links',
        'owner': 'owner',
        'scope': 'scope',
        'scope_owner': 'scopeOwner',
        'type': 'type'
    }

    def __init__(self, attached_bus_ob_id=None, attached_bus_ob_rec_id=None, attachment_file_id=None, attachment_file_name=None, attachment_file_type=None, attachment_id=None, attachment_type=None, bus_ob_id=None, bus_ob_rec_id=None, comment=None, created=None, display_text=None, links=None, owner=None, scope=None, scope_owner=None, type=None, local_vars_configuration=None):  # noqa: E501
        """Attachment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attached_bus_ob_id = None
        self._attached_bus_ob_rec_id = None
        self._attachment_file_id = None
        self._attachment_file_name = None
        self._attachment_file_type = None
        self._attachment_id = None
        self._attachment_type = None
        self._bus_ob_id = None
        self._bus_ob_rec_id = None
        self._comment = None
        self._created = None
        self._display_text = None
        self._links = None
        self._owner = None
        self._scope = None
        self._scope_owner = None
        self._type = None
        self.discriminator = None

        if attached_bus_ob_id is not None:
            self.attached_bus_ob_id = attached_bus_ob_id
        if attached_bus_ob_rec_id is not None:
            self.attached_bus_ob_rec_id = attached_bus_ob_rec_id
        if attachment_file_id is not None:
            self.attachment_file_id = attachment_file_id
        if attachment_file_name is not None:
            self.attachment_file_name = attachment_file_name
        if attachment_file_type is not None:
            self.attachment_file_type = attachment_file_type
        if attachment_id is not None:
            self.attachment_id = attachment_id
        if attachment_type is not None:
            self.attachment_type = attachment_type
        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if bus_ob_rec_id is not None:
            self.bus_ob_rec_id = bus_ob_rec_id
        if comment is not None:
            self.comment = comment
        if created is not None:
            self.created = created
        if display_text is not None:
            self.display_text = display_text
        if links is not None:
            self.links = links
        if owner is not None:
            self.owner = owner
        if scope is not None:
            self.scope = scope
        if scope_owner is not None:
            self.scope_owner = scope_owner
        if type is not None:
            self.type = type

    @property
    def attached_bus_ob_id(self):
        """Gets the attached_bus_ob_id of this Attachment.  # noqa: E501


        :return: The attached_bus_ob_id of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._attached_bus_ob_id

    @attached_bus_ob_id.setter
    def attached_bus_ob_id(self, attached_bus_ob_id):
        """Sets the attached_bus_ob_id of this Attachment.


        :param attached_bus_ob_id: The attached_bus_ob_id of this Attachment.  # noqa: E501
        :type: str
        """

        self._attached_bus_ob_id = attached_bus_ob_id

    @property
    def attached_bus_ob_rec_id(self):
        """Gets the attached_bus_ob_rec_id of this Attachment.  # noqa: E501


        :return: The attached_bus_ob_rec_id of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._attached_bus_ob_rec_id

    @attached_bus_ob_rec_id.setter
    def attached_bus_ob_rec_id(self, attached_bus_ob_rec_id):
        """Sets the attached_bus_ob_rec_id of this Attachment.


        :param attached_bus_ob_rec_id: The attached_bus_ob_rec_id of this Attachment.  # noqa: E501
        :type: str
        """

        self._attached_bus_ob_rec_id = attached_bus_ob_rec_id

    @property
    def attachment_file_id(self):
        """Gets the attachment_file_id of this Attachment.  # noqa: E501


        :return: The attachment_file_id of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_file_id

    @attachment_file_id.setter
    def attachment_file_id(self, attachment_file_id):
        """Sets the attachment_file_id of this Attachment.


        :param attachment_file_id: The attachment_file_id of this Attachment.  # noqa: E501
        :type: str
        """

        self._attachment_file_id = attachment_file_id

    @property
    def attachment_file_name(self):
        """Gets the attachment_file_name of this Attachment.  # noqa: E501


        :return: The attachment_file_name of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_file_name

    @attachment_file_name.setter
    def attachment_file_name(self, attachment_file_name):
        """Sets the attachment_file_name of this Attachment.


        :param attachment_file_name: The attachment_file_name of this Attachment.  # noqa: E501
        :type: str
        """

        self._attachment_file_name = attachment_file_name

    @property
    def attachment_file_type(self):
        """Gets the attachment_file_type of this Attachment.  # noqa: E501


        :return: The attachment_file_type of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_file_type

    @attachment_file_type.setter
    def attachment_file_type(self, attachment_file_type):
        """Sets the attachment_file_type of this Attachment.


        :param attachment_file_type: The attachment_file_type of this Attachment.  # noqa: E501
        :type: str
        """

        self._attachment_file_type = attachment_file_type

    @property
    def attachment_id(self):
        """Gets the attachment_id of this Attachment.  # noqa: E501


        :return: The attachment_id of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this Attachment.


        :param attachment_id: The attachment_id of this Attachment.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def attachment_type(self):
        """Gets the attachment_type of this Attachment.  # noqa: E501


        :return: The attachment_type of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this Attachment.


        :param attachment_type: The attachment_type of this Attachment.  # noqa: E501
        :type: str
        """
        allowed_values = ["Imported", "Linked", "URL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and attachment_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `attachment_type` ({0}), must be one of {1}"  # noqa: E501
                .format(attachment_type, allowed_values)
            )

        self._attachment_type = attachment_type

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this Attachment.  # noqa: E501


        :return: The bus_ob_id of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this Attachment.


        :param bus_ob_id: The bus_ob_id of this Attachment.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def bus_ob_rec_id(self):
        """Gets the bus_ob_rec_id of this Attachment.  # noqa: E501


        :return: The bus_ob_rec_id of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_rec_id

    @bus_ob_rec_id.setter
    def bus_ob_rec_id(self, bus_ob_rec_id):
        """Sets the bus_ob_rec_id of this Attachment.


        :param bus_ob_rec_id: The bus_ob_rec_id of this Attachment.  # noqa: E501
        :type: str
        """

        self._bus_ob_rec_id = bus_ob_rec_id

    @property
    def comment(self):
        """Gets the comment of this Attachment.  # noqa: E501


        :return: The comment of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Attachment.


        :param comment: The comment of this Attachment.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def created(self):
        """Gets the created of this Attachment.  # noqa: E501


        :return: The created of this Attachment.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Attachment.


        :param created: The created of this Attachment.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def display_text(self):
        """Gets the display_text of this Attachment.  # noqa: E501


        :return: The display_text of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._display_text

    @display_text.setter
    def display_text(self, display_text):
        """Sets the display_text of this Attachment.


        :param display_text: The display_text of this Attachment.  # noqa: E501
        :type: str
        """

        self._display_text = display_text

    @property
    def links(self):
        """Gets the links of this Attachment.  # noqa: E501


        :return: The links of this Attachment.  # noqa: E501
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Attachment.


        :param links: The links of this Attachment.  # noqa: E501
        :type: list[Link]
        """

        self._links = links

    @property
    def owner(self):
        """Gets the owner of this Attachment.  # noqa: E501


        :return: The owner of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this Attachment.


        :param owner: The owner of this Attachment.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def scope(self):
        """Gets the scope of this Attachment.  # noqa: E501


        :return: The scope of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this Attachment.


        :param scope: The scope of this Attachment.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Global", "Team", "Persona", "SecurityGroup", "User", "UserInPersona", "OtherUsers", "Core", "BusIntel", "FromResource", "Site", "Custom"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and scope not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def scope_owner(self):
        """Gets the scope_owner of this Attachment.  # noqa: E501


        :return: The scope_owner of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._scope_owner

    @scope_owner.setter
    def scope_owner(self, scope_owner):
        """Sets the scope_owner of this Attachment.


        :param scope_owner: The scope_owner of this Attachment.  # noqa: E501
        :type: str
        """

        self._scope_owner = scope_owner

    @property
    def type(self):
        """Gets the type of this Attachment.  # noqa: E501


        :return: The type of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Attachment.


        :param type: The type of this Attachment.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "File", "FileManagerFile", "BusOb", "History", "Other"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Attachment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Attachment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class SaveWorkgroupMemberRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'customer_record_id': 'str',
        'workgroup_id': 'str',
        'customer_is_workgroup_manager': 'bool'
    }

    attribute_map = {
        'customer_record_id': 'customerRecordId',
        'workgroup_id': 'workgroupId',
        'customer_is_workgroup_manager': 'customerIsWorkgroupManager'
    }

    def __init__(self, customer_record_id=None, workgroup_id=None, customer_is_workgroup_manager=None, local_vars_configuration=None):  # noqa: E501
        """SaveWorkgroupMemberRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._customer_record_id = None
        self._workgroup_id = None
        self._customer_is_workgroup_manager = None
        self.discriminator = None

        if customer_record_id is not None:
            self.customer_record_id = customer_record_id
        if workgroup_id is not None:
            self.workgroup_id = workgroup_id
        if customer_is_workgroup_manager is not None:
            self.customer_is_workgroup_manager = customer_is_workgroup_manager

    @property
    def customer_record_id(self):
        """Gets the customer_record_id of this SaveWorkgroupMemberRequest.  # noqa: E501


        :return: The customer_record_id of this SaveWorkgroupMemberRequest.  # noqa: E501
        :rtype: str
        """
        return self._customer_record_id

    @customer_record_id.setter
    def customer_record_id(self, customer_record_id):
        """Sets the customer_record_id of this SaveWorkgroupMemberRequest.


        :param customer_record_id: The customer_record_id of this SaveWorkgroupMemberRequest.  # noqa: E501
        :type: str
        """

        self._customer_record_id = customer_record_id

    @property
    def workgroup_id(self):
        """Gets the workgroup_id of this SaveWorkgroupMemberRequest.  # noqa: E501


        :return: The workgroup_id of this SaveWorkgroupMemberRequest.  # noqa: E501
        :rtype: str
        """
        return self._workgroup_id

    @workgroup_id.setter
    def workgroup_id(self, workgroup_id):
        """Sets the workgroup_id of this SaveWorkgroupMemberRequest.


        :param workgroup_id: The workgroup_id of this SaveWorkgroupMemberRequest.  # noqa: E501
        :type: str
        """

        self._workgroup_id = workgroup_id

    @property
    def customer_is_workgroup_manager(self):
        """Gets the customer_is_workgroup_manager of this SaveWorkgroupMemberRequest.  # noqa: E501


        :return: The customer_is_workgroup_manager of this SaveWorkgroupMemberRequest.  # noqa: E501
        :rtype: bool
        """
        return self._customer_is_workgroup_manager

    @customer_is_workgroup_manager.setter
    def customer_is_workgroup_manager(self, customer_is_workgroup_manager):
        """Sets the customer_is_workgroup_manager of this SaveWorkgroupMemberRequest.


        :param customer_is_workgroup_manager: The customer_is_workgroup_manager of this SaveWorkgroupMemberRequest.  # noqa: E501
        :type: bool
        """

        self._customer_is_workgroup_manager = customer_is_workgroup_manager

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveWorkgroupMemberRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveWorkgroupMemberRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class Role(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'browser_client_custom_view_id': 'str',
        'business_object_exclude_list': 'list[str]',
        'culture': 'str',
        'description': 'str',
        'mobile_client_custom_view_id': 'str',
        'primary_bus_ob_id': 'str',
        'role_id': 'str',
        'role_name': 'str',
        'smart_client_custom_view_id': 'str'
    }

    attribute_map = {
        'browser_client_custom_view_id': 'browserClientCustomViewId',
        'business_object_exclude_list': 'businessObjectExcludeList',
        'culture': 'culture',
        'description': 'description',
        'mobile_client_custom_view_id': 'mobileClientCustomViewId',
        'primary_bus_ob_id': 'primaryBusObId',
        'role_id': 'roleId',
        'role_name': 'roleName',
        'smart_client_custom_view_id': 'smartClientCustomViewId'
    }

    def __init__(self, browser_client_custom_view_id=None, business_object_exclude_list=None, culture=None, description=None, mobile_client_custom_view_id=None, primary_bus_ob_id=None, role_id=None, role_name=None, smart_client_custom_view_id=None, local_vars_configuration=None):  # noqa: E501
        """Role - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._browser_client_custom_view_id = None
        self._business_object_exclude_list = None
        self._culture = None
        self._description = None
        self._mobile_client_custom_view_id = None
        self._primary_bus_ob_id = None
        self._role_id = None
        self._role_name = None
        self._smart_client_custom_view_id = None
        self.discriminator = None

        if browser_client_custom_view_id is not None:
            self.browser_client_custom_view_id = browser_client_custom_view_id
        if business_object_exclude_list is not None:
            self.business_object_exclude_list = business_object_exclude_list
        if culture is not None:
            self.culture = culture
        if description is not None:
            self.description = description
        if mobile_client_custom_view_id is not None:
            self.mobile_client_custom_view_id = mobile_client_custom_view_id
        if primary_bus_ob_id is not None:
            self.primary_bus_ob_id = primary_bus_ob_id
        if role_id is not None:
            self.role_id = role_id
        if role_name is not None:
            self.role_name = role_name
        if smart_client_custom_view_id is not None:
            self.smart_client_custom_view_id = smart_client_custom_view_id

    @property
    def browser_client_custom_view_id(self):
        """Gets the browser_client_custom_view_id of this Role.  # noqa: E501


        :return: The browser_client_custom_view_id of this Role.  # noqa: E501
        :rtype: str
        """
        return self._browser_client_custom_view_id

    @browser_client_custom_view_id.setter
    def browser_client_custom_view_id(self, browser_client_custom_view_id):
        """Sets the browser_client_custom_view_id of this Role.


        :param browser_client_custom_view_id: The browser_client_custom_view_id of this Role.  # noqa: E501
        :type: str
        """

        self._browser_client_custom_view_id = browser_client_custom_view_id

    @property
    def business_object_exclude_list(self):
        """Gets the business_object_exclude_list of this Role.  # noqa: E501


        :return: The business_object_exclude_list of this Role.  # noqa: E501
        :rtype: list[str]
        """
        return self._business_object_exclude_list

    @business_object_exclude_list.setter
    def business_object_exclude_list(self, business_object_exclude_list):
        """Sets the business_object_exclude_list of this Role.


        :param business_object_exclude_list: The business_object_exclude_list of this Role.  # noqa: E501
        :type: list[str]
        """

        self._business_object_exclude_list = business_object_exclude_list

    @property
    def culture(self):
        """Gets the culture of this Role.  # noqa: E501


        :return: The culture of this Role.  # noqa: E501
        :rtype: str
        """
        return self._culture

    @culture.setter
    def culture(self, culture):
        """Sets the culture of this Role.


        :param culture: The culture of this Role.  # noqa: E501
        :type: str
        """

        self._culture = culture

    @property
    def description(self):
        """Gets the description of this Role.  # noqa: E501


        :return: The description of this Role.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Role.


        :param description: The description of this Role.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def mobile_client_custom_view_id(self):
        """Gets the mobile_client_custom_view_id of this Role.  # noqa: E501


        :return: The mobile_client_custom_view_id of this Role.  # noqa: E501
        :rtype: str
        """
        return self._mobile_client_custom_view_id

    @mobile_client_custom_view_id.setter
    def mobile_client_custom_view_id(self, mobile_client_custom_view_id):
        """Sets the mobile_client_custom_view_id of this Role.


        :param mobile_client_custom_view_id: The mobile_client_custom_view_id of this Role.  # noqa: E501
        :type: str
        """

        self._mobile_client_custom_view_id = mobile_client_custom_view_id

    @property
    def primary_bus_ob_id(self):
        """Gets the primary_bus_ob_id of this Role.  # noqa: E501


        :return: The primary_bus_ob_id of this Role.  # noqa: E501
        :rtype: str
        """
        return self._primary_bus_ob_id

    @primary_bus_ob_id.setter
    def primary_bus_ob_id(self, primary_bus_ob_id):
        """Sets the primary_bus_ob_id of this Role.


        :param primary_bus_ob_id: The primary_bus_ob_id of this Role.  # noqa: E501
        :type: str
        """

        self._primary_bus_ob_id = primary_bus_ob_id

    @property
    def role_id(self):
        """Gets the role_id of this Role.  # noqa: E501


        :return: The role_id of this Role.  # noqa: E501
        :rtype: str
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this Role.


        :param role_id: The role_id of this Role.  # noqa: E501
        :type: str
        """

        self._role_id = role_id

    @property
    def role_name(self):
        """Gets the role_name of this Role.  # noqa: E501


        :return: The role_name of this Role.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this Role.


        :param role_name: The role_name of this Role.  # noqa: E501
        :type: str
        """

        self._role_name = role_name

    @property
    def smart_client_custom_view_id(self):
        """Gets the smart_client_custom_view_id of this Role.  # noqa: E501


        :return: The smart_client_custom_view_id of this Role.  # noqa: E501
        :rtype: str
        """
        return self._smart_client_custom_view_id

    @smart_client_custom_view_id.setter
    def smart_client_custom_view_id(self, smart_client_custom_view_id):
        """Sets the smart_client_custom_view_id of this Role.


        :param smart_client_custom_view_id: The smart_client_custom_view_id of this Role.  # noqa: E501
        :type: str
        """

        self._smart_client_custom_view_id = smart_client_custom_view_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Role):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Role):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class UserV2(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_locked': 'bool',
        'create_date_time': 'datetime',
        'display_name': 'str',
        'fields': 'list[FieldTemplateItem]',
        'last_password_reset_date': 'datetime',
        'last_reset_date_time': 'datetime',
        'ldap_required': 'bool',
        'password_never_expires': 'bool',
        'public_id': 'str',
        'record_id': 'str',
        'security_group_id': 'str',
        'short_display_name': 'str',
        'user_cannot_change_password': 'bool',
        'user_must_reset_password_at_next_login': 'bool',
        'error_code': 'str',
        'error_message': 'str',
        'has_error': 'bool'
    }

    attribute_map = {
        'account_locked': 'accountLocked',
        'create_date_time': 'createDateTime',
        'display_name': 'displayName',
        'fields': 'fields',
        'last_password_reset_date': 'lastPasswordResetDate',
        'last_reset_date_time': 'lastResetDateTime',
        'ldap_required': 'ldapRequired',
        'password_never_expires': 'passwordNeverExpires',
        'public_id': 'publicId',
        'record_id': 'recordId',
        'security_group_id': 'securityGroupId',
        'short_display_name': 'shortDisplayName',
        'user_cannot_change_password': 'userCannotChangePassword',
        'user_must_reset_password_at_next_login': 'userMustResetPasswordAtNextLogin',
        'error_code': 'errorCode',
        'error_message': 'errorMessage',
        'has_error': 'hasError'
    }

    def __init__(self, account_locked=None, create_date_time=None, display_name=None, fields=None, last_password_reset_date=None, last_reset_date_time=None, ldap_required=None, password_never_expires=None, public_id=None, record_id=None, security_group_id=None, short_display_name=None, user_cannot_change_password=None, user_must_reset_password_at_next_login=None, error_code=None, error_message=None, has_error=None, local_vars_configuration=None):  # noqa: E501
        """UserV2 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_locked = None
        self._create_date_time = None
        self._display_name = None
        self._fields = None
        self._last_password_reset_date = None
        self._last_reset_date_time = None
        self._ldap_required = None
        self._password_never_expires = None
        self._public_id = None
        self._record_id = None
        self._security_group_id = None
        self._short_display_name = None
        self._user_cannot_change_password = None
        self._user_must_reset_password_at_next_login = None
        self._error_code = None
        self._error_message = None
        self._has_error = None
        self.discriminator = None

        if account_locked is not None:
            self.account_locked = account_locked
        if create_date_time is not None:
            self.create_date_time = create_date_time
        if display_name is not None:
            self.display_name = display_name
        if fields is not None:
            self.fields = fields
        if last_password_reset_date is not None:
            self.last_password_reset_date = last_password_reset_date
        if last_reset_date_time is not None:
            self.last_reset_date_time = last_reset_date_time
        if ldap_required is not None:
            self.ldap_required = ldap_required
        if password_never_expires is not None:
            self.password_never_expires = password_never_expires
        if public_id is not None:
            self.public_id = public_id
        if record_id is not None:
            self.record_id = record_id
        if security_group_id is not None:
            self.security_group_id = security_group_id
        if short_display_name is not None:
            self.short_display_name = short_display_name
        if user_cannot_change_password is not None:
            self.user_cannot_change_password = user_cannot_change_password
        if user_must_reset_password_at_next_login is not None:
            self.user_must_reset_password_at_next_login = user_must_reset_password_at_next_login
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message
        if has_error is not None:
            self.has_error = has_error

    @property
    def account_locked(self):
        """Gets the account_locked of this UserV2.  # noqa: E501


        :return: The account_locked of this UserV2.  # noqa: E501
        :rtype: bool
        """
        return self._account_locked

    @account_locked.setter
    def account_locked(self, account_locked):
        """Sets the account_locked of this UserV2.


        :param account_locked: The account_locked of this UserV2.  # noqa: E501
        :type: bool
        """

        self._account_locked = account_locked

    @property
    def create_date_time(self):
        """Gets the create_date_time of this UserV2.  # noqa: E501


        :return: The create_date_time of this UserV2.  # noqa: E501
        :rtype: datetime
        """
        return self._create_date_time

    @create_date_time.setter
    def create_date_time(self, create_date_time):
        """Sets the create_date_time of this UserV2.


        :param create_date_time: The create_date_time of this UserV2.  # noqa: E501
        :type: datetime
        """

        self._create_date_time = create_date_time

    @property
    def display_name(self):
        """Gets the display_name of this UserV2.  # noqa: E501


        :return: The display_name of this UserV2.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this UserV2.


        :param display_name: The display_name of this UserV2.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def fields(self):
        """Gets the fields of this UserV2.  # noqa: E501


        :return: The fields of this UserV2.  # noqa: E501
        :rtype: list[FieldTemplateItem]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this UserV2.


        :param fields: The fields of this UserV2.  # noqa: E501
        :type: list[FieldTemplateItem]
        """

        self._fields = fields

    @property
    def last_password_reset_date(self):
        """Gets the last_password_reset_date of this UserV2.  # noqa: E501


        :return: The last_password_reset_date of this UserV2.  # noqa: E501
        :rtype: datetime
        """
        return self._last_password_reset_date

    @last_password_reset_date.setter
    def last_password_reset_date(self, last_password_reset_date):
        """Sets the last_password_reset_date of this UserV2.


        :param last_password_reset_date: The last_password_reset_date of this UserV2.  # noqa: E501
        :type: datetime
        """

        self._last_password_reset_date = last_password_reset_date

    @property
    def last_reset_date_time(self):
        """Gets the last_reset_date_time of this UserV2.  # noqa: E501


        :return: The last_reset_date_time of this UserV2.  # noqa: E501
        :rtype: datetime
        """
        return self._last_reset_date_time

    @last_reset_date_time.setter
    def last_reset_date_time(self, last_reset_date_time):
        """Sets the last_reset_date_time of this UserV2.


        :param last_reset_date_time: The last_reset_date_time of this UserV2.  # noqa: E501
        :type: datetime
        """

        self._last_reset_date_time = last_reset_date_time

    @property
    def ldap_required(self):
        """Gets the ldap_required of this UserV2.  # noqa: E501


        :return: The ldap_required of this UserV2.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_required

    @ldap_required.setter
    def ldap_required(self, ldap_required):
        """Sets the ldap_required of this UserV2.


        :param ldap_required: The ldap_required of this UserV2.  # noqa: E501
        :type: bool
        """

        self._ldap_required = ldap_required

    @property
    def password_never_expires(self):
        """Gets the password_never_expires of this UserV2.  # noqa: E501


        :return: The password_never_expires of this UserV2.  # noqa: E501
        :rtype: bool
        """
        return self._password_never_expires

    @password_never_expires.setter
    def password_never_expires(self, password_never_expires):
        """Sets the password_never_expires of this UserV2.


        :param password_never_expires: The password_never_expires of this UserV2.  # noqa: E501
        :type: bool
        """

        self._password_never_expires = password_never_expires

    @property
    def public_id(self):
        """Gets the public_id of this UserV2.  # noqa: E501


        :return: The public_id of this UserV2.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this UserV2.


        :param public_id: The public_id of this UserV2.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def record_id(self):
        """Gets the record_id of this UserV2.  # noqa: E501


        :return: The record_id of this UserV2.  # noqa: E501
        :rtype: str
        """
        return self._record_id

    @record_id.setter
    def record_id(self, record_id):
        """Sets the record_id of this UserV2.


        :param record_id: The record_id of this UserV2.  # noqa: E501
        :type: str
        """

        self._record_id = record_id

    @property
    def security_group_id(self):
        """Gets the security_group_id of this UserV2.  # noqa: E501


        :return: The security_group_id of this UserV2.  # noqa: E501
        :rtype: str
        """
        return self._security_group_id

    @security_group_id.setter
    def security_group_id(self, security_group_id):
        """Sets the security_group_id of this UserV2.


        :param security_group_id: The security_group_id of this UserV2.  # noqa: E501
        :type: str
        """

        self._security_group_id = security_group_id

    @property
    def short_display_name(self):
        """Gets the short_display_name of this UserV2.  # noqa: E501


        :return: The short_display_name of this UserV2.  # noqa: E501
        :rtype: str
        """
        return self._short_display_name

    @short_display_name.setter
    def short_display_name(self, short_display_name):
        """Sets the short_display_name of this UserV2.


        :param short_display_name: The short_display_name of this UserV2.  # noqa: E501
        :type: str
        """

        self._short_display_name = short_display_name

    @property
    def user_cannot_change_password(self):
        """Gets the user_cannot_change_password of this UserV2.  # noqa: E501


        :return: The user_cannot_change_password of this UserV2.  # noqa: E501
        :rtype: bool
        """
        return self._user_cannot_change_password

    @user_cannot_change_password.setter
    def user_cannot_change_password(self, user_cannot_change_password):
        """Sets the user_cannot_change_password of this UserV2.


        :param user_cannot_change_password: The user_cannot_change_password of this UserV2.  # noqa: E501
        :type: bool
        """

        self._user_cannot_change_password = user_cannot_change_password

    @property
    def user_must_reset_password_at_next_login(self):
        """Gets the user_must_reset_password_at_next_login of this UserV2.  # noqa: E501


        :return: The user_must_reset_password_at_next_login of this UserV2.  # noqa: E501
        :rtype: bool
        """
        return self._user_must_reset_password_at_next_login

    @user_must_reset_password_at_next_login.setter
    def user_must_reset_password_at_next_login(self, user_must_reset_password_at_next_login):
        """Sets the user_must_reset_password_at_next_login of this UserV2.


        :param user_must_reset_password_at_next_login: The user_must_reset_password_at_next_login of this UserV2.  # noqa: E501
        :type: bool
        """

        self._user_must_reset_password_at_next_login = user_must_reset_password_at_next_login

    @property
    def error_code(self):
        """Gets the error_code of this UserV2.  # noqa: E501


        :return: The error_code of this UserV2.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this UserV2.


        :param error_code: The error_code of this UserV2.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this UserV2.  # noqa: E501


        :return: The error_message of this UserV2.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this UserV2.


        :param error_message: The error_message of this UserV2.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def has_error(self):
        """Gets the has_error of this UserV2.  # noqa: E501


        :return: The has_error of this UserV2.  # noqa: E501
        :rtype: bool
        """
        return self._has_error

    @has_error.setter
    def has_error(self, has_error):
        """Sets the has_error of this UserV2.


        :param has_error: The has_error of this UserV2.  # noqa: E501
        :type: bool
        """

        self._has_error = has_error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserV2):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserV2):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pycherwell.api_client import ApiClient
from pycherwell.exceptions import (
    ApiTypeError,
    ApiValueError
)


class CoreApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def core_delete_gallery_image_by_stand_in_key_v1(self, standinkey, **kwargs):  # noqa: E501
        """Delete a gallery image  # noqa: E501

        Endpoint to delete a gallery image.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_delete_gallery_image_by_stand_in_key_v1(standinkey, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str standinkey: The StandIn key for the gallery image to delete. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_delete_gallery_image_by_stand_in_key_v1_with_http_info(standinkey, **kwargs)  # noqa: E501

    def core_delete_gallery_image_by_stand_in_key_v1_with_http_info(self, standinkey, **kwargs):  # noqa: E501
        """Delete a gallery image  # noqa: E501

        Endpoint to delete a gallery image.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_delete_gallery_image_by_stand_in_key_v1_with_http_info(standinkey, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str standinkey: The StandIn key for the gallery image to delete. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['standinkey']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_delete_gallery_image_by_stand_in_key_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'standinkey' is set
        if self.api_client.client_side_validation and ('standinkey' not in local_var_params or  # noqa: E501
                                                        local_var_params['standinkey'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `standinkey` when calling `core_delete_gallery_image_by_stand_in_key_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'standinkey' in local_var_params:
            path_params['standinkey'] = local_var_params['standinkey']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/deletegalleryimage/standinkey/{standinkey}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_gallery_image_v1(self, name, **kwargs):  # noqa: E501
        """Get built-in images  # noqa: E501

        Operation that gets built-in images. If you are requesting an icon (.ico), you can specify width and height.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_image_v1(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: Image name and folder location in the Image Manager. Parameter must begin with \"[PlugIn]Images;\" and then a period-separated list of folders. Example: \"[PlugIn]Images;Images.Common.Cherwell.ico\". (required)
        :param int width: Specify the width (icons only).
        :param int height: Specify the height (icons only).
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_gallery_image_v1_with_http_info(name, **kwargs)  # noqa: E501

    def core_get_gallery_image_v1_with_http_info(self, name, **kwargs):  # noqa: E501
        """Get built-in images  # noqa: E501

        Operation that gets built-in images. If you are requesting an icon (.ico), you can specify width and height.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_image_v1_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: Image name and folder location in the Image Manager. Parameter must begin with \"[PlugIn]Images;\" and then a period-separated list of folders. Example: \"[PlugIn]Images;Images.Common.Cherwell.ico\". (required)
        :param int width: Specify the width (icons only).
        :param int height: Specify the height (icons only).
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['name', 'width', 'height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_gallery_image_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `core_get_gallery_image_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []
        if 'width' in local_var_params and local_var_params['width'] is not None:  # noqa: E501
            query_params.append(('width', local_var_params['width']))  # noqa: E501
        if 'height' in local_var_params and local_var_params['height'] is not None:  # noqa: E501
            query_params.append(('height', local_var_params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getgalleryimage/name/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_gallery_images_folder_v1(self, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get gallery images by scope, scopeowner, and folder  # noqa: E501

        Get gallery images for the specified scope, scopeowner, and folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_images_folder_v1(scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get gallery images for. (required)
        :param str scopeowner: the scopeowner to get gallery images for. (required)
        :param str folder: The folder to get gallery images for. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_gallery_images_folder_v1_with_http_info(scope, scopeowner, folder, **kwargs)  # noqa: E501

    def core_get_gallery_images_folder_v1_with_http_info(self, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get gallery images by scope, scopeowner, and folder  # noqa: E501

        Get gallery images for the specified scope, scopeowner, and folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_images_folder_v1_with_http_info(scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get gallery images for. (required)
        :param str scopeowner: the scopeowner to get gallery images for. (required)
        :param str folder: The folder to get gallery images for. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'scopeowner', 'folder', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_gallery_images_folder_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `core_get_gallery_images_folder_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `core_get_gallery_images_folder_v1`")  # noqa: E501
        # verify the required parameter 'folder' is set
        if self.api_client.client_side_validation and ('folder' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder` when calling `core_get_gallery_images_folder_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'folder' in local_var_params:
            path_params['folder'] = local_var_params['folder']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getgalleryimages/scope/{scope}/scopeowner/{scopeowner}/folder/{folder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_gallery_images_scope_owner_v1(self, scope, scopeowner, **kwargs):  # noqa: E501
        """Get gallery images by scope and scopeowner  # noqa: E501

        Get all gallery images for the specified scope and scope owner.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_images_scope_owner_v1(scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get gallery images for. (required)
        :param str scopeowner: The scopeowner to get gallery images for. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_gallery_images_scope_owner_v1_with_http_info(scope, scopeowner, **kwargs)  # noqa: E501

    def core_get_gallery_images_scope_owner_v1_with_http_info(self, scope, scopeowner, **kwargs):  # noqa: E501
        """Get gallery images by scope and scopeowner  # noqa: E501

        Get all gallery images for the specified scope and scope owner.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_images_scope_owner_v1_with_http_info(scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get gallery images for. (required)
        :param str scopeowner: The scopeowner to get gallery images for. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'scopeowner', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_gallery_images_scope_owner_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `core_get_gallery_images_scope_owner_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `core_get_gallery_images_scope_owner_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getgalleryimages/scope/{scope}/scopeowner/{scopeowner}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_gallery_images_scope_v1(self, scope, **kwargs):  # noqa: E501
        """Get gallery images by scope  # noqa: E501

        Get all gallery images for the specified scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_images_scope_v1(scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get the images for. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_gallery_images_scope_v1_with_http_info(scope, **kwargs)  # noqa: E501

    def core_get_gallery_images_scope_v1_with_http_info(self, scope, **kwargs):  # noqa: E501
        """Get gallery images by scope  # noqa: E501

        Get all gallery images for the specified scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_images_scope_v1_with_http_info(scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get the images for. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_gallery_images_scope_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `core_get_gallery_images_scope_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getgalleryimages/scope/{scope}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_gallery_images_v1(self, **kwargs):  # noqa: E501
        """Get all gallery images  # noqa: E501

        Get all the gallery images in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_images_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_gallery_images_v1_with_http_info(**kwargs)  # noqa: E501

    def core_get_gallery_images_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get all gallery images  # noqa: E501

        Get all the gallery images in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_gallery_images_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_gallery_images_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getgalleryimages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_stored_value_v1(self, stand_in_key, **kwargs):  # noqa: E501
        """Get a  stored value  # noqa: E501

        Get a stored value by its StandIn key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_value_v1(stand_in_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str stand_in_key: The StandIn key for the Stored Value you would like to retrieve. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StoredValueResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_stored_value_v1_with_http_info(stand_in_key, **kwargs)  # noqa: E501

    def core_get_stored_value_v1_with_http_info(self, stand_in_key, **kwargs):  # noqa: E501
        """Get a  stored value  # noqa: E501

        Get a stored value by its StandIn key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_value_v1_with_http_info(stand_in_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str stand_in_key: The StandIn key for the Stored Value you would like to retrieve. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StoredValueResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['stand_in_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_stored_value_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'stand_in_key' is set
        if self.api_client.client_side_validation and ('stand_in_key' not in local_var_params or  # noqa: E501
                                                        local_var_params['stand_in_key'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `stand_in_key` when calling `core_get_stored_value_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'stand_in_key' in local_var_params:
            path_params['standInKey'] = local_var_params['stand_in_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getstoredvalue/standinkey/{standInKey}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StoredValueResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_stored_values_folder_v1(self, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get stored values by folder  # noqa: E501

        Get stored values for the specified folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_values_folder_v1(scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope for which to get stored values. (required)
        :param str scopeowner: The scope owner for which to get stored values. (required)
        :param str folder: The folder for which to get stored values. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_stored_values_folder_v1_with_http_info(scope, scopeowner, folder, **kwargs)  # noqa: E501

    def core_get_stored_values_folder_v1_with_http_info(self, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get stored values by folder  # noqa: E501

        Get stored values for the specified folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_values_folder_v1_with_http_info(scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope for which to get stored values. (required)
        :param str scopeowner: The scope owner for which to get stored values. (required)
        :param str folder: The folder for which to get stored values. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'scopeowner', 'folder', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_stored_values_folder_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `core_get_stored_values_folder_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `core_get_stored_values_folder_v1`")  # noqa: E501
        # verify the required parameter 'folder' is set
        if self.api_client.client_side_validation and ('folder' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder` when calling `core_get_stored_values_folder_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'folder' in local_var_params:
            path_params['folder'] = local_var_params['folder']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/storedvalues/scope/{scope}/scopeowner/{scopeowner}/folder/{folder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_stored_values_scope_owner_v1(self, scope, scopeowner, **kwargs):  # noqa: E501
        """Get stored values by scope owner  # noqa: E501

        Get stored values for the specified scope and scope owner.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_values_scope_owner_v1(scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope for which to get stored values. (required)
        :param str scopeowner: The scope owner for which to get stored values. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_stored_values_scope_owner_v1_with_http_info(scope, scopeowner, **kwargs)  # noqa: E501

    def core_get_stored_values_scope_owner_v1_with_http_info(self, scope, scopeowner, **kwargs):  # noqa: E501
        """Get stored values by scope owner  # noqa: E501

        Get stored values for the specified scope and scope owner.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_values_scope_owner_v1_with_http_info(scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope for which to get stored values. (required)
        :param str scopeowner: The scope owner for which to get stored values. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'scopeowner', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_stored_values_scope_owner_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `core_get_stored_values_scope_owner_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `core_get_stored_values_scope_owner_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/storedvalues/scope/{scope}/scopeowner/{scopeowner}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_stored_values_scope_v1(self, scope, **kwargs):  # noqa: E501
        """Get stored values by scope  # noqa: E501

        Get all the stored values for the specified scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_values_scope_v1(scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope for which to get stored values. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_stored_values_scope_v1_with_http_info(scope, **kwargs)  # noqa: E501

    def core_get_stored_values_scope_v1_with_http_info(self, scope, **kwargs):  # noqa: E501
        """Get stored values by scope  # noqa: E501

        Get all the stored values for the specified scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_values_scope_v1_with_http_info(scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope for which to get stored values. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_stored_values_scope_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `core_get_stored_values_scope_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/storedvalues/scope/{scope}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_stored_values_v1(self, **kwargs):  # noqa: E501
        """Gets all the stored values in the system  # noqa: E501

        Get all the stored values in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_values_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_stored_values_v1_with_http_info(**kwargs)  # noqa: E501

    def core_get_stored_values_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Gets all the stored values in the system  # noqa: E501

        Get all the stored values in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_stored_values_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Flag to include hyperlinks in results. Default is false.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_stored_values_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/storedvalues', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_get_views_v1(self, **kwargs):  # noqa: E501
        """Get a list of the views  # noqa: E501

        Operation to get a list of views that are configured in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_views_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ViewsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_get_views_v1_with_http_info(**kwargs)  # noqa: E501

    def core_get_views_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get a list of the views  # noqa: E501

        Operation to get a list of views that are configured in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_get_views_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ViewsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_get_views_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getviews', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ViewsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_save_gallery_image_v1(self, save_gallery_image_request, **kwargs):  # noqa: E501
        """Create or update a gallery image  # noqa: E501

        Endpoint to Create or update a gallery image. To create a new gallery image leave the StandIn key blank. To update a gallery image provide the StandIn key of the gallery image you want to update.</br>There are three different ImageTypes allowed: Imported, Url, and File. To use the Imported image type, provide the filename in the Name property, with extension, and provide the image data in a Base64 encoded format in the Base64EncodedImageData property. The max file size is 512k.</br>To use the Url image type,  provide the full network share path to the file in the Name property, ie: \"\\\\\\\\\\\\\\\\networkshare\\\\\\somefolder\\\\\\somefile.jpg\". If the file is not accessible to all users it will not visible to all users.</br>To use the File image type, provide the full path to the file in the Name property, ie: \"C:\\\\\\somefolder\\\\\\somfile.jpg\". If the file is not accessible to all users it will not visible to all users.</br>When creating or updating an image, Name and ImageType are always required, and if the image type is \"Imported\", then the Base64EncodedImageData is also required. </br>scope, scopeowner, and folder can all be updated independently.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_save_gallery_image_v1(save_gallery_image_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveGalleryImageRequest save_gallery_image_request: To create a new gallery image leave the StandIn key blank. To update a gallery image provide the StandIn key of the gallery image you want to update.</br>There are three different ImageTypes allowed: Imported, Url, and File. To use the Imported image type, provide the filename in the Name property, with extension, and provide the image data in a Base64 encoded format in the Base64EncodedImageData property. The max file size is 512k.</br>To use the Url image type,  provide the full network share path to the file in the Name property, ie: \"\\\\\\\\\\\\\\\\networkshare\\\\\\somefolder\\\\\\somefile.jpg\". If the file is not accessible to all users it will not visible to all users.</br>To use the File image type, provide the full path to the file in the Name property, ie: \"C:\\\\\\somefolder\\\\\\somfile.jpg\". If the file is not accessible to all users it will not visible to all users.</br>When creating or updating an image, Name and ImageType are always required, and if the image type is \"Imported\", then the Base64EncodedImageData is also required. </br>scope, scopeowner, and folder can all be updated independently. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SaveGalleryImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_save_gallery_image_v1_with_http_info(save_gallery_image_request, **kwargs)  # noqa: E501

    def core_save_gallery_image_v1_with_http_info(self, save_gallery_image_request, **kwargs):  # noqa: E501
        """Create or update a gallery image  # noqa: E501

        Endpoint to Create or update a gallery image. To create a new gallery image leave the StandIn key blank. To update a gallery image provide the StandIn key of the gallery image you want to update.</br>There are three different ImageTypes allowed: Imported, Url, and File. To use the Imported image type, provide the filename in the Name property, with extension, and provide the image data in a Base64 encoded format in the Base64EncodedImageData property. The max file size is 512k.</br>To use the Url image type,  provide the full network share path to the file in the Name property, ie: \"\\\\\\\\\\\\\\\\networkshare\\\\\\somefolder\\\\\\somefile.jpg\". If the file is not accessible to all users it will not visible to all users.</br>To use the File image type, provide the full path to the file in the Name property, ie: \"C:\\\\\\somefolder\\\\\\somfile.jpg\". If the file is not accessible to all users it will not visible to all users.</br>When creating or updating an image, Name and ImageType are always required, and if the image type is \"Imported\", then the Base64EncodedImageData is also required. </br>scope, scopeowner, and folder can all be updated independently.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_save_gallery_image_v1_with_http_info(save_gallery_image_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveGalleryImageRequest save_gallery_image_request: To create a new gallery image leave the StandIn key blank. To update a gallery image provide the StandIn key of the gallery image you want to update.</br>There are three different ImageTypes allowed: Imported, Url, and File. To use the Imported image type, provide the filename in the Name property, with extension, and provide the image data in a Base64 encoded format in the Base64EncodedImageData property. The max file size is 512k.</br>To use the Url image type,  provide the full network share path to the file in the Name property, ie: \"\\\\\\\\\\\\\\\\networkshare\\\\\\somefolder\\\\\\somefile.jpg\". If the file is not accessible to all users it will not visible to all users.</br>To use the File image type, provide the full path to the file in the Name property, ie: \"C:\\\\\\somefolder\\\\\\somfile.jpg\". If the file is not accessible to all users it will not visible to all users.</br>When creating or updating an image, Name and ImageType are always required, and if the image type is \"Imported\", then the Base64EncodedImageData is also required. </br>scope, scopeowner, and folder can all be updated independently. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SaveGalleryImageResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['save_gallery_image_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_save_gallery_image_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'save_gallery_image_request' is set
        if self.api_client.client_side_validation and ('save_gallery_image_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['save_gallery_image_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `save_gallery_image_request` when calling `core_save_gallery_image_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_gallery_image_request' in local_var_params:
            body_params = local_var_params['save_gallery_image_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/savegalleryimage', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SaveGalleryImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_save_stored_value_v1(self, save_stored_value_request, **kwargs):  # noqa: E501
        """Create or update a stored value  # noqa: E501

        Operation to create or update a stored value. To update, specify the StandIn key for the stored value to update. To create leave StandIn key blank, and provide a name, a scope, a type, and a value.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_save_stored_value_v1(save_stored_value_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveStoredValueRequest save_stored_value_request: The stored value to create or update. To update include the StandIn key for the associated stored value. To create, name, scope, type, and value are required. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StoredValueResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_save_stored_value_v1_with_http_info(save_stored_value_request, **kwargs)  # noqa: E501

    def core_save_stored_value_v1_with_http_info(self, save_stored_value_request, **kwargs):  # noqa: E501
        """Create or update a stored value  # noqa: E501

        Operation to create or update a stored value. To update, specify the StandIn key for the stored value to update. To create leave StandIn key blank, and provide a name, a scope, a type, and a value.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_save_stored_value_v1_with_http_info(save_stored_value_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveStoredValueRequest save_stored_value_request: The stored value to create or update. To update include the StandIn key for the associated stored value. To create, name, scope, type, and value are required. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StoredValueResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['save_stored_value_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_save_stored_value_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'save_stored_value_request' is set
        if self.api_client.client_side_validation and ('save_stored_value_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['save_stored_value_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `save_stored_value_request` when calling `core_save_stored_value_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_stored_value_request' in local_var_params:
            body_params = local_var_params['save_stored_value_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/savestoredvalue', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StoredValueResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def core_set_culture_v1(self, culturecode, **kwargs):  # noqa: E501
        """Set the culture for the current user  # noqa: E501

        Operation to update the current users culture by culture code. This returns a new access token that has the updated information in it.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_set_culture_v1(culturecode, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str culturecode: The culture code to set for the current user. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.core_set_culture_v1_with_http_info(culturecode, **kwargs)  # noqa: E501

    def core_set_culture_v1_with_http_info(self, culturecode, **kwargs):  # noqa: E501
        """Set the culture for the current user  # noqa: E501

        Operation to update the current users culture by culture code. This returns a new access token that has the updated information in it.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.core_set_culture_v1_with_http_info(culturecode, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str culturecode: The culture code to set for the current user. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['culturecode']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method core_set_culture_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'culturecode' is set
        if self.api_client.client_side_validation and ('culturecode' not in local_var_params or  # noqa: E501
                                                        local_var_params['culturecode'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `culturecode` when calling `core_set_culture_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'culturecode' in local_var_params:
            path_params['culturecode'] = local_var_params['culturecode']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/setculture/culturecode/{culturecode}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
